﻿using Dynamicweb.Environment;
using Dynamicweb.Extensibility.Notifications;
using System;

namespace Dynamicweb.Ecommerce.LiveIntegration.NotificationSubscribers
{
    /// <summary>
    /// Sends an update to the ERP when an order line is removed.
    /// </summary>
    /// <seealso cref="NotificationSubscriberBase" />
    [Subscribe(Ecommerce.Notifications.Ecommerce.Cart.Line.Removed)]
    public class OrderLineRemoved : NotificationSubscriberBase
    {
        /// <summary>
        /// Handles the notification.
        /// </summary>
        /// <param name="notification">The notification.</param>
        /// <param name="args">The args.</param>
        public override void OnNotify(string notification, NotificationArgs args)
        {
            var myArgs = (Ecommerce.Notifications.Ecommerce.Cart.Line.RemovedArgs)args;
            if (EnabledAndActive() && myArgs?.Cart != null && !IsEmptyCartCalled())
            {
                UpdateOrder(myArgs.Cart, "Line.Removed");
            }
        }

        /// <summary>
        /// Determines whether the current request is a request to clear the cart.
        /// </summary>
        private bool IsEmptyCartCalled()
        {
            string cartCmd = Context.Current.Request.GetString("CartCmd").ToLower();
            return !string.IsNullOrEmpty(cartCmd) && string.Equals(cartCmd, "emptycart", StringComparison.OrdinalIgnoreCase);
        }
    }
}